/* Copyright (c) 2006, 2010, Oracle and/or its affiliates. All rights reserved.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */

#include <my_global.h>
#include <sql_priv.h>
#include <stdlib.h>
#include <ctype.h>
#include <mysql_version.h>
#include <mysql/plugin.h>
#include <my_dir.h>
#include "my_pthread.h"                         // pthread_handler_t
#include "my_sys.h"                             // my_write, my_malloc
#include "m_string.h"                           // strlen
#include "sql_plugin.h"                         // st_plugin_int

/*
  Disable __attribute__() on non-gcc compilers.
*/
#if !defined(__attribute__) && !defined(__GNUC__)
#define __attribute__(A)
#endif



/*
  Initialize the aastat example at server start or plugin installation.

  SYNOPSIS
    aastat_example_plugin_init()

  DESCRIPTION
    Starts up heartbeatbeat thread

  RETURN VALUE
    0                    success
    1                    failure (cannot happen)
*/

static int aastat_example_plugin_init(void *p)
{

  DBUG_ENTER("aastat_example_plugin_init");  
  
  DBUG_RETURN(0);
}


/*
  Terminate the aastat example at server shutdown or plugin deinstallation.

  SYNOPSIS
    aastat_example_plugin_deinit()
    Does nothing.

  RETURN VALUE
    0                    success
    1                    failure (cannot happen)

*/

static int aastat_example_plugin_deinit(void *p)
{
  DBUG_ENTER("aastat_example_plugin_deinit");
  DBUG_RETURN(0);
}

/*
 Plugin status variables for SHOW STATUS
 */

static struct st_mysql_show_var status_vars[] =
{
	{ "AASTAT_example", (char *) "demo", SHOW_CHAR },
	{ 0, 0, (enum_mysql_show_type) 0 } 
};



static struct st_mysql_daemon aastat_example_plugin=
{ MYSQL_DAEMON_INTERFACE_VERSION  };

/*
  Plugin library descriptor
*/

mysql_declare_plugin(aastat_example)
{
  MYSQL_DAEMON_PLUGIN,
  &aastat_example_plugin,
  "aastat_example",
  "Guy Lichtman",
  "Demonstrates bug with status variables not being cleaned up if first in list.",
  PLUGIN_LICENSE_GPL,
  aastat_example_plugin_init, /* Plugin Init */
  aastat_example_plugin_deinit, /* Plugin Deinit */
  0x0100 /* 1.0 */,
  status_vars,                       /* status variables                */
  NULL,                       /* system variables                */
  NULL,                       /* config options                  */
  0,                          /* flags                           */
}
mysql_declare_plugin_end;
